CCL: /home/chisarie/Documents/lsst_ccl/CCL/include/ccl_lsst_specs.h File Reference

CCL

Data Structures | Macros | Functions
ccl_lsst_specs.h File Reference
`#include "ccl_core.h"`
`#include "math.h"`
`#include "gsl/gsl_integration.h"`
`#include "gsl/gsl_spline.h"`

Go to the source code of this file.

## Data Structures
struct | user_pz_info

## Macros
#define | DNDZ_WL_CONS 1
#define | DNDZ_WL_FID 2
#define | DNDZ_WL_OPT 3
#define | DNDZ_NC 4
#define | Z_MIN_SOURCES 0.1
#define | Z_MAX_SOURCES 3.0

## Functions
double | ccl_specs_bias_clustering (ccl_cosmology *cosmo, double a, int *status)
void | ccl_specs_dNdz_tomog (double z, int dNdz_type, double bin_zmin, double bin_zmax, user_pz_info *user_info, double *tomoout, int *status)
user_pz_info * | ccl_specs_create_photoz_info (void *user_params, double(*user_pz_func)(double, double, void *, int *))
void | ccl_specs_free_photoz_info (user_pz_info *my_photoz_info)
double | ccl_specs_sigmaz_clustering (double z)
double | ccl_specs_sigmaz_sources (double z)

## Macro Definition Documentation

## ◆ DNDZ_NC

#define DNDZ_NC 4

## ◆ DNDZ_WL_CONS

#define DNDZ_WL_CONS 1

## ◆ DNDZ_WL_FID

#define DNDZ_WL_FID 2

## ◆ DNDZ_WL_OPT

#define DNDZ_WL_OPT 3

## ◆ Z_MAX_SOURCES

#define Z_MAX_SOURCES 3.0

## ◆ Z_MIN_SOURCES

#define Z_MIN_SOURCES 0.1

## Function Documentation

## ◆ ccl_specs_bias_clustering()

double ccl_specs_bias_clustering | ( | ccl_cosmology * | cosmo,
|  | double | a,
|  | int * | status
| ) |  |

Compute b(a), the bias of the clustering sample of a cosmology at a given scale factor This is input from LSS group.

Parameters

  cosmo | Cosmological parameters
  a | scale factor, normalized to a=1 today.
  status | Status flag. 0 if there are no errors, nonzero otherwise. For specific cases see documentation for ccl_error.

Returns
  b, the bias at a in cosmo

## ◆ ccl_specs_create_photoz_info()

user_pz_info* ccl_specs_create_photoz_info | ( | void * | user_params,
|  | double(*)(double, double, void *, int *) | user_pz_func
| ) |  |

This function creates a structure amalgamating the user-input information on the photo-z model, P(z) plus some parameters.

Parameters

  user_params | User-defined parameters for the P(z) function
  user_pz_func | P(z) function

Returns
  a structure with the user-provided P(z) and parameters

## ◆ ccl_specs_dNdz_tomog()

void ccl_specs_dNdz_tomog | ( | double | z,
|  | int | dNdz_type,
|  | double | bin_zmin,
|  | double | bin_zmax,
|  | user_pz_info * | user_info,
|  | double * | tomoout,
|  | int * | status
| ) |  |

Return dNdz in a particular tomographic bin, convolved with a photo-z model (defined by the user), and normalized.

Parameters

  z | redshift
  dNdz_type | the choice of dN/dz from Chang+
  bin_zmin | the minimum redshift of the tomorgraphic bin
  bin_zmax | the maximum redshift of the tomographic bin
  user_info | the user P(z) info struct
  tomoout | the output dN/dz
  status | Status flag. 0 if there are no errors, nonzero otherwise.

Returns
  void

## ◆ ccl_specs_free_photoz_info()

void ccl_specs_free_photoz_info | ( | user_pz_info * | my_photoz_info | ) |

Free memory holding the structure containing user-input photoz information.

Parameters

  my_photoz_info | that holds user-defined P(z) and parameters

Returns
  void

## ◆ ccl_specs_sigmaz_clustering()

double ccl_specs_sigmaz_clustering | ( | double | z | ) |

Return sigma(z), the photo-z dispersion, for the clustering sample This is if you want to assume Gaussian uncertainties.

Parameters

  z | redshift

Returns
  sigma(z) for the clustering sample

## ◆ ccl_specs_sigmaz_sources()

double ccl_specs_sigmaz_sources | ( | double | z | ) |

Return sigma(z), the photo-z dispersion, for the lensing sample This is if you want to assume Gaussian uncertainties.

Parameters

  z | redshift

Returns
  sigma(z) for the lensing sample